@@ -8,6 +8,8 @@
     :copyright: (c) 2010 by Dan Jacob.
     :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
+
 import StringIO
 import unittest
 import twill
@@ -102,7 +104,8 @@ class TestCase(unittest.TestCase):
 
         :param name: template name
         """
-        assert _is_signals, "Signals not supported"
+        if not _is_signals:
+            raise RuntimeError, "Signals not supported"
 
         for template, context in self.templates:
             if template.name == name:
@@ -122,7 +125,8 @@ class TestCase(unittest.TestCase):
 
         :param name: name of variable
         """
-        assert _is_signals, "Signals not supported"
+        if not _is_signals:
+            raise RuntimeError, "Signals not supported"
         
         for template, context in self.templates:
             if name in context:
@@ -134,7 +138,7 @@ class TestCase(unittest.TestCase):
         Checks if given name exists in the template context
         and equals the given value.
 
-        :param name:name of context variable
+        :param name: name of context variable
         :param value: value to check against
         """
 
